==> sinosun-ui-0.1.9.tgz: package/es/support/native/NativeSuportApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler } from "./JSBridge.js";
//js与app数据通信类

var NativeSupportApi = function () {
    function NativeSupportApi() {
        _classCallCheck(this, NativeSupportApi);
    }

    _createClass(NativeSupportApi, [{
        key: 'getCurrentUserInfo',

        //描述：获取登录用户信息
        //场景：如网络请求前获取统一获取用户的cpyId、uaid
        //对应SnJSBridge接口：GetUserInfoFunction
        value: function getCurrentUserInfo() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('GetUserInfoFunction', data);
        }
        //描述：根据cpyId、uaid查询用户信息
        //场景：如查询用户名称、icon等信息
        //对应SnJSBridge接口：QueryUserInfoFunction

    }, {
        key: 'queryUserInfoById',
        value: function queryUserInfoById() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('QueryUserInfoFunction', data);
        }
        //描述：获取用户头像
        //场景：mPaaS版本使用
        //对应SnJSBridge接口：QueryUserIconFunction

    }, {
        key: 'queryUserIcon',
        value: function queryUserIcon() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('QueryUserIconFunction', data);
        }
        //描述：数据加密
        //场景：https请求，可考虑去掉数据加解密，但有些银行使用安全工具扫描会有漏洞
        //对应SnJSBridge接口：EncryptionFunction

    }, {
        key: 'encryptionData',
        value: function encryptionData(data) {
            return callHandler('EncryptionFunction', data);
        }
        //描述：数据解密
        //场景：https请求，可考虑去掉数据加解密，但有些银行使用安全工具扫描会有漏洞
        //对应SnJSBridge接口：DecryptionFunction

    }, {
        key: 'decryptionData',
        value: function decryptionData(data) {
            return callHandler('DecryptionFunction', data);
        }
        //描述：获取企业信息及状态
        //场景：可改成从服务器查询，但效率低
        //对应SnJSBridge接口：QueryCompanyDetailFunction

    }, {
        key: 'queryCompanyInfo',
        value: function queryCompanyInfo(cpyInfo) {
            return callHandler('QueryCompanyDetailFunction', cpyInfo);
        }
        //描述：调用app获取配置信息
        //场景：如mstp host、prodId
        //对应SnJSBridge接口：GetAppConfigFunction

    }, {
        key: 'getAppConfig',
        value: function getAppConfig() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('GetAppConfigFunction', data);
        }
        //描述：检查当前网络情况
        //对应SnJSBridge接口：CheckNetWorkFunction

    }, {
        key: 'checkNetWork',
        value: function checkNetWork() {
            return callHandler('CheckNetWorkFunction', '');
        }
        //描述：数据签名
        //场景：审批表单签名，业务上可以考虑去掉
        //对应SnJSBridge接口：SignDataFunction

    }, {
        key: 'signData',
        value: function signData(data) {
            return callHandler('SignDataFunction', data);
        }
        //描述：实时监听gps信息
        //场景：获取app的定位信息，主要在考勤使用
        //对应SnJSBridge接口：LocationObserverFunction

    }, {
        key: 'locationObserver',
        value: function locationObserver(data) {
            return callHandler('LocationObserverFunction', data);
        }
        //描述：注册监听app的推送消息
        //场景：如审批列表页面，收到审批推送消息，可自动刷新页面
        //对应SnJSBridge接口：RegisterCommonPushFunction

    }, {
        key: 'registerCommonEvent',
        value: function registerCommonEvent() {
            return callHandler('RegisterCommonPushFunction', '');
        }
        //描述：H5通知APP消息
        //场景：审批有未读消息通知app工作台标小红点
        //对应SnJSBridge接口：SendActionFunction

    }, {
        key: 'sendMsgToApp',
        value: function sendMsgToApp(data) {
            return callHandler('SendActionFunction', data);
        }
        //描述：H5通知app小应用动作事件
        //场景：埋点相关，用于通知埋点事件
        //对应SnJSBridge接口：notifyAppActionEvent

    }, {
        key: 'notifyAppActionEvent',
        value: function notifyAppActionEvent(data) {
            return callHandler('NotifyAppActionEvent', data);
        }
        //描述：注册H5通知app页面名称（唯一key）
        //场景：埋点相关，用于审批申请页面埋点，同一个apply页面，需要通知app区分不同模板
        //对应SnJSBridge接口：NotifyAppPageKeyFunction

    }, {
        key: 'setPageKey',
        value: function setPageKey(pageName) {
            return callHandler('NotifyAppPageKeyFunction', { type: 2, pageKey: pageName });
        }
        //描述：通过完整文件url下载文件
        //场景：部分应用有文件不在FS上，无法使用js fs接口下载，需要通过app下载（代发工资、批量转账模板文件）可考虑使用Filepreview预览接口扩展实现
        //对应SnJSBridge接口：DownloadFunction

    }, {
        key: 'fileDownload',
        value: function fileDownload() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('DownloadFunction', data);
        }
        //描述：文件上传接口
        //场景：解决mPaaS离线包js上传附件跨域问题，由app上传附件，仅mPaaS版本使用、北京微信小程序上传附件
        //对应SnJSBridge接口：FileUploadFunction

    }, {
        key: 'fileUplod',
        value: function fileUplod() {
            return callHandler('FileUploadFunction', '');
        }
    }]);

    return NativeSupportApi;
}();

export default new NativeSupportApi();

==> sinosun-ui-0.2.5.tgz: package/es/support/native/NativeSuportApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler } from "./JSBridge.js";
//js与app数据通信类

var NativeSupportApi = function () {
    function NativeSupportApi() {
        _classCallCheck(this, NativeSupportApi);
    }

    _createClass(NativeSupportApi, null, [{
        key: 'getCurrentUserInfo',

        //描述：获取登录用户信息
        //场景：如网络请求前获取统一获取用户的cpyId、uaid
        //对应SnJSBridge接口：GetUserInfoFunction
        value: function getCurrentUserInfo() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('GetUserInfoFunction', data);
        }
        //描述：根据cpyId、uaid查询用户信息
        //场景：如查询用户名称、icon等信息
        //对应SnJSBridge接口：QueryUserInfoFunction

    }, {
        key: 'queryUserInfoById',
        value: function queryUserInfoById() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('QueryUserInfoFunction', data);
        }
        //描述：获取用户头像
        //场景：mPaaS版本使用
        //对应SnJSBridge接口：QueryUserIconFunction

    }, {
        key: 'queryUserIcon',
        value: function queryUserIcon() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('QueryUserIconFunction', data);
        }
        //描述：数据加密
        //场景：https请求，可考虑去掉数据加解密，但有些银行使用安全工具扫描会有漏洞
        //对应SnJSBridge接口：EncryptionFunction

    }, {
        key: 'encryptionData',
        value: function encryptionData(data) {
            return callHandler('EncryptionFunction', data);
        }
        //描述：数据解密
        //场景：https请求，可考虑去掉数据加解密，但有些银行使用安全工具扫描会有漏洞
        //对应SnJSBridge接口：DecryptionFunction

    }, {
        key: 'decryptionData',
        value: function decryptionData(data) {
            return callHandler('DecryptionFunction', data);
        }
        //描述：获取企业信息及状态
        //场景：可改成从服务器查询，但效率低
        //对应SnJSBridge接口：QueryCompanyDetailFunction

    }, {
        key: 'queryCompanyInfo',
        value: function queryCompanyInfo(cpyInfo) {
            return callHandler('QueryCompanyDetailFunction', cpyInfo);
        }
        //描述：调用app获取配置信息
        //场景：如mstp host、prodId
        //对应SnJSBridge接口：GetAppConfigFunction

    }, {
        key: 'getAppConfig',
        value: function getAppConfig() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('GetAppConfigFunction', data);
        }
        //描述：检查当前网络情况
        //对应SnJSBridge接口：CheckNetWorkFunction

    }, {
        key: 'checkNetWork',
        value: function checkNetWork() {
            return callHandler('CheckNetWorkFunction', '');
        }
        //描述：数据签名
        //场景：审批表单签名，业务上可以考虑去掉
        //对应SnJSBridge接口：SignDataFunction

    }, {
        key: 'signData',
        value: function signData(data) {
            return callHandler('SignDataFunction', data);
        }
        //描述：实时监听gps信息
        //场景：获取app的定位信息，主要在考勤使用
        //对应SnJSBridge接口：LocationObserverFunction

    }, {
        key: 'locationObserver',
        value: function locationObserver(data) {
            return callHandler('LocationObserverFunction', data);
        }
        //描述：注册监听app的推送消息
        //场景：如审批列表页面，收到审批推送消息，可自动刷新页面
        //对应SnJSBridge接口：RegisterCommonPushFunction

    }, {
        key: 'registerCommonEvent',
        value: function registerCommonEvent() {
            return callHandler('RegisterCommonPushFunction', '');
        }
        //描述：H5通知APP消息
        //场景：审批有未读消息通知app工作台标小红点
        //对应SnJSBridge接口：SendActionFunction

    }, {
        key: 'sendMsgToApp',
        value: function sendMsgToApp(data) {
            return callHandler('SendActionFunction', data);
        }
        //描述：H5通知app小应用动作事件
        //场景：埋点相关，用于通知埋点事件
        //对应SnJSBridge接口：notifyAppActionEvent

    }, {
        key: 'notifyAppActionEvent',
        value: function notifyAppActionEvent(data) {
            return callHandler('NotifyAppActionEvent', data);
        }
        //描述：注册H5通知app页面名称（唯一key）
        //场景：埋点相关，用于审批申请页面埋点，同一个apply页面，需要通知app区分不同模板
        //对应SnJSBridge接口：NotifyAppPageKeyFunction

    }, {
        key: 'setPageKey',
        value: function setPageKey(pageName) {
            return callHandler('NotifyAppPageKeyFunction', { type: 2, pageKey: pageName });
        }
        //描述：通过完整文件url下载文件
        //场景：部分应用有文件不在FS上，无法使用js fs接口下载，需要通过app下载（代发工资、批量转账模板文件）可考虑使用Filepreview预览接口扩展实现
        //对应SnJSBridge接口：DownloadFunction

    }, {
        key: 'fileDownload',
        value: function fileDownload() {
            var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

            return callHandler('DownloadFunction', data);
        }
        //描述：文件上传接口
        //场景：解决mPaaS离线包js上传附件跨域问题，由app上传附件，仅mPaaS版本使用、北京微信小程序上传附件
        //对应SnJSBridge接口：FileUploadFunction

    }, {
        key: 'fileUplod',
        value: function fileUplod() {
            return callHandler('FileUploadFunction', '');
        }
    }]);

    return NativeSupportApi;
}();

export default NativeSupportApi;
